use strict;
use warnings;
use Test::More tests => 1;

use WebService::Solr;
use WebService::Solr::Field;
use WebService::Solr::Document;
use WebService::Solr::Query;
use WebService::Solr::Response;

pass( 'All modules loaded' );
done_testing();
